@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-11-09'; # DATE
 our $DIST = 'Dist-Zilla-Plugin-InsertDistImage'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 use Moose;
 with (
@@ -72,7 +72,7 @@ sub munge_files {
                 unless $found;
             $url = "$url";
         } else {
-            $url = $self->zilla->get_shared_file_url($hosting, $paths[0]);
+            $url = $self->get_shared_file_url($hosting, $paths[0]);
         }
 
         "=begin html\n\n<img src=\"$url\" />\n\n=end html\n\n";
@@ -129,7 +129,7 @@ Dist::Zilla::Plugin::InsertDistImage - Insert images contained in distribution i
 
 =head1 VERSION
 
-This document describes version 0.006 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2023-11-09.
+This document describes version 0.007 of Dist::Zilla::Plugin::InsertDistImage (from Perl distribution Dist-Zilla-Plugin-InsertDistImage), released on 2023-11-09.
 
 =head1 SYNOPSIS
 
